@@ -52,7 +52,7 @@ ${\$instance->data} = sort_hash_ref( $instance->data );
 # To see how the filter is working see test "t/04_lexicon_store_JSON.t".
 () = print Locale::TextDomain::OO::Lexicon::StoreJSON->new->to_json, "\n";
 
-#$Id: 04_lexicon_store_JSON_utf-8.pl 472 2014-01-21 16:37:44Z steffenw $
+#$Id: 04_lexicon_store_JSON_utf-8.pl 491 2014-05-10 15:08:16Z steffenw $
 
 __END__
 
@@ -64,19 +64,19 @@ Lexicon "en-gb:cat:dom" loaded from hash.
     '' => {
       'charset' => 'UTF-8',
       'nplurals' => 1,
-      'plural' => 'n'
+      'plural' => 'n != 1',
     },
     'appointment{MSG_KEY_SEPARATOR}date for GBP{PLURAL_SEPARATOR}dates for GBP' => {
       'msgstr' => [
           "date for \xc2\xa3", # "\xc2\xa3" is £ as UTF-8
           "dates for \xc2\xa3",
       ],
-    }
+    },
   },
   'i-default::' => {
     '' => {
       'nplurals' => 2,
-      'plural' => 'n != 1'
-    }
-  }
+      'plural' => 'n != 1',
+    },
+  },
 }
